from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING

from typing import List


from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import Dict
import datetime
from typing import cast, List
from typing import cast
from ..types import UNSET, Unset
from typing import Union
from dateutil.parser import isoparse

if TYPE_CHECKING:
  from ..models.employee_infos import EmployeeInfos
  from ..models.assignment import Assignment
  from ..models.employee_role import EmployeeRole
  from ..models.phone_lite import PhoneLite





T = TypeVar("T", bound="EmployeeComplete")


@_attrs_define
class EmployeeComplete:
    """ Description complète d'un compte

        Attributes:
            uid (Union[Unset, str]): Identifiant LDAP
            login (Union[Unset, str]): Identifiant de connexion
            repository_id (Union[Unset, str]): Matricule du compte dans le référentiel de la provenance des informations
            mail (Union[Unset, str]): Adresse e-mail
            rot13mail (Union[Unset, str]): Adresse e-mail chiffrée (ROT13)
            custom_rot_mail (Union[Unset, str]): Adresse e-mail chiffrée (chiffrement personnalisé)
            chosen_firstname (Union[Unset, str]): Prénom d'usage
            usualname (Union[Unset, str]): Nom usuel
            displayname (Union[Unset, str]): Nom d'affichage
            displayname_for_file (Union[Unset, str]): Nom d'affichage sans caractères spéciaux ni espace
            phone (Union[Unset, PhoneLite]): Description allégée d'un numéro de téléphone
            main_assignment_code (Union[Unset, str]): Code de l'affectation principale
            status (Union[Unset, List[str]]): Liste des statuts
            is_active_employee (Union[Unset, bool]): Témoin de l'activité professionnel du compte
            is_hosted (Union[Unset, bool]): Témoin de l'hébergement du compte
            expiration (Union[Unset, datetime.datetime]): Date de fin de validité
            modified (Union[Unset, datetime.datetime]): Date de dernière modification
            employee_id (Union[Unset, str]): Numéro d'employé
            lastnames (Union[Unset, List[str]]): Noms
            forenames (Union[Unset, List[str]]): Prénoms
            assignments_codes (Union[Unset, List[str]]): Liste des codes d'affectations
            mobiles (Union[Unset, List['PhoneLite']]): Numéros de mobiles
            internal_lines (Union[Unset, List['PhoneLite']]): Numéros internes
            external_lines (Union[Unset, List['PhoneLite']]): Numéros externes
            assignments (Union[Unset, List['Assignment']]): Affectations
            infos (Union[Unset, List['EmployeeInfos']]): Informations détaillés de personnel
            roles (Union[Unset, List['EmployeeRole']]): Rôles contextuels
            memberships (Union[Unset, List[str]]): Liste des corps
            cnu (Union[Unset, List[str]]): Liste des CNU
            bap (Union[Unset, List[str]]): Liste de BAP
            contracts (Union[Unset, List[str]]): Liste de types de contrats
            networks (Union[Unset, List[str]]): Liste de VLAN accessibles
     """

    uid: Union[Unset, str] = UNSET
    login: Union[Unset, str] = UNSET
    repository_id: Union[Unset, str] = UNSET
    mail: Union[Unset, str] = UNSET
    rot13mail: Union[Unset, str] = UNSET
    custom_rot_mail: Union[Unset, str] = UNSET
    chosen_firstname: Union[Unset, str] = UNSET
    usualname: Union[Unset, str] = UNSET
    displayname: Union[Unset, str] = UNSET
    displayname_for_file: Union[Unset, str] = UNSET
    phone: Union[Unset, 'PhoneLite'] = UNSET
    main_assignment_code: Union[Unset, str] = UNSET
    status: Union[Unset, List[str]] = UNSET
    is_active_employee: Union[Unset, bool] = UNSET
    is_hosted: Union[Unset, bool] = UNSET
    expiration: Union[Unset, datetime.datetime] = UNSET
    modified: Union[Unset, datetime.datetime] = UNSET
    employee_id: Union[Unset, str] = UNSET
    lastnames: Union[Unset, List[str]] = UNSET
    forenames: Union[Unset, List[str]] = UNSET
    assignments_codes: Union[Unset, List[str]] = UNSET
    mobiles: Union[Unset, List['PhoneLite']] = UNSET
    internal_lines: Union[Unset, List['PhoneLite']] = UNSET
    external_lines: Union[Unset, List['PhoneLite']] = UNSET
    assignments: Union[Unset, List['Assignment']] = UNSET
    infos: Union[Unset, List['EmployeeInfos']] = UNSET
    roles: Union[Unset, List['EmployeeRole']] = UNSET
    memberships: Union[Unset, List[str]] = UNSET
    cnu: Union[Unset, List[str]] = UNSET
    bap: Union[Unset, List[str]] = UNSET
    contracts: Union[Unset, List[str]] = UNSET
    networks: Union[Unset, List[str]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        from ..models.employee_infos import EmployeeInfos
        from ..models.assignment import Assignment
        from ..models.employee_role import EmployeeRole
        from ..models.phone_lite import PhoneLite
        uid = self.uid

        login = self.login

        repository_id = self.repository_id

        mail = self.mail

        rot13mail = self.rot13mail

        custom_rot_mail = self.custom_rot_mail

        chosen_firstname = self.chosen_firstname

        usualname = self.usualname

        displayname = self.displayname

        displayname_for_file = self.displayname_for_file

        phone: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.phone, Unset):
            phone = self.phone.to_dict()

        main_assignment_code = self.main_assignment_code

        status: Union[Unset, List[str]] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status





        is_active_employee = self.is_active_employee

        is_hosted = self.is_hosted

        expiration: Union[Unset, str] = UNSET
        if not isinstance(self.expiration, Unset):
            expiration = self.expiration.isoformat()

        modified: Union[Unset, str] = UNSET
        if not isinstance(self.modified, Unset):
            modified = self.modified.isoformat()

        employee_id = self.employee_id

        lastnames: Union[Unset, List[str]] = UNSET
        if not isinstance(self.lastnames, Unset):
            lastnames = self.lastnames





        forenames: Union[Unset, List[str]] = UNSET
        if not isinstance(self.forenames, Unset):
            forenames = self.forenames





        assignments_codes: Union[Unset, List[str]] = UNSET
        if not isinstance(self.assignments_codes, Unset):
            assignments_codes = self.assignments_codes





        mobiles: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.mobiles, Unset):
            mobiles = []
            for mobiles_item_data in self.mobiles:
                mobiles_item = mobiles_item_data.to_dict()
                mobiles.append(mobiles_item)





        internal_lines: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.internal_lines, Unset):
            internal_lines = []
            for internal_lines_item_data in self.internal_lines:
                internal_lines_item = internal_lines_item_data.to_dict()
                internal_lines.append(internal_lines_item)





        external_lines: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.external_lines, Unset):
            external_lines = []
            for external_lines_item_data in self.external_lines:
                external_lines_item = external_lines_item_data.to_dict()
                external_lines.append(external_lines_item)





        assignments: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.assignments, Unset):
            assignments = []
            for assignments_item_data in self.assignments:
                assignments_item = assignments_item_data.to_dict()
                assignments.append(assignments_item)





        infos: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.infos, Unset):
            infos = []
            for infos_item_data in self.infos:
                infos_item = infos_item_data.to_dict()
                infos.append(infos_item)





        roles: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.roles, Unset):
            roles = []
            for roles_item_data in self.roles:
                roles_item = roles_item_data.to_dict()
                roles.append(roles_item)





        memberships: Union[Unset, List[str]] = UNSET
        if not isinstance(self.memberships, Unset):
            memberships = self.memberships





        cnu: Union[Unset, List[str]] = UNSET
        if not isinstance(self.cnu, Unset):
            cnu = self.cnu





        bap: Union[Unset, List[str]] = UNSET
        if not isinstance(self.bap, Unset):
            bap = self.bap





        contracts: Union[Unset, List[str]] = UNSET
        if not isinstance(self.contracts, Unset):
            contracts = self.contracts





        networks: Union[Unset, List[str]] = UNSET
        if not isinstance(self.networks, Unset):
            networks = self.networks






        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if uid is not UNSET:
            field_dict["uid"] = uid
        if login is not UNSET:
            field_dict["login"] = login
        if repository_id is not UNSET:
            field_dict["repositoryId"] = repository_id
        if mail is not UNSET:
            field_dict["mail"] = mail
        if rot13mail is not UNSET:
            field_dict["rot13mail"] = rot13mail
        if custom_rot_mail is not UNSET:
            field_dict["customRotMail"] = custom_rot_mail
        if chosen_firstname is not UNSET:
            field_dict["chosenFirstname"] = chosen_firstname
        if usualname is not UNSET:
            field_dict["usualname"] = usualname
        if displayname is not UNSET:
            field_dict["displayname"] = displayname
        if displayname_for_file is not UNSET:
            field_dict["displaynameForFile"] = displayname_for_file
        if phone is not UNSET:
            field_dict["phone"] = phone
        if main_assignment_code is not UNSET:
            field_dict["mainAssignmentCode"] = main_assignment_code
        if status is not UNSET:
            field_dict["status"] = status
        if is_active_employee is not UNSET:
            field_dict["isActiveEmployee"] = is_active_employee
        if is_hosted is not UNSET:
            field_dict["isHosted"] = is_hosted
        if expiration is not UNSET:
            field_dict["expiration"] = expiration
        if modified is not UNSET:
            field_dict["modified"] = modified
        if employee_id is not UNSET:
            field_dict["employeeId"] = employee_id
        if lastnames is not UNSET:
            field_dict["lastnames"] = lastnames
        if forenames is not UNSET:
            field_dict["forenames"] = forenames
        if assignments_codes is not UNSET:
            field_dict["assignmentsCodes"] = assignments_codes
        if mobiles is not UNSET:
            field_dict["mobiles"] = mobiles
        if internal_lines is not UNSET:
            field_dict["internalLines"] = internal_lines
        if external_lines is not UNSET:
            field_dict["externalLines"] = external_lines
        if assignments is not UNSET:
            field_dict["assignments"] = assignments
        if infos is not UNSET:
            field_dict["infos"] = infos
        if roles is not UNSET:
            field_dict["roles"] = roles
        if memberships is not UNSET:
            field_dict["memberships"] = memberships
        if cnu is not UNSET:
            field_dict["cnu"] = cnu
        if bap is not UNSET:
            field_dict["bap"] = bap
        if contracts is not UNSET:
            field_dict["contracts"] = contracts
        if networks is not UNSET:
            field_dict["networks"] = networks

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.employee_infos import EmployeeInfos
        from ..models.assignment import Assignment
        from ..models.employee_role import EmployeeRole
        from ..models.phone_lite import PhoneLite
        if not src_dict:
            return None
        d = src_dict.copy()
        uid = d.pop("uid", UNSET)

        login = d.pop("login", UNSET)

        repository_id = d.pop("repositoryId", UNSET)

        mail = d.pop("mail", UNSET)

        rot13mail = d.pop("rot13mail", UNSET)

        custom_rot_mail = d.pop("customRotMail", UNSET)

        chosen_firstname = d.pop("chosenFirstname", UNSET)

        usualname = d.pop("usualname", UNSET)

        displayname = d.pop("displayname", UNSET)

        displayname_for_file = d.pop("displaynameForFile", UNSET)

        _phone = d.pop("phone", UNSET)
        phone: Union[Unset, PhoneLite]
        if isinstance(_phone,  Unset) or _phone is None:
            phone = UNSET
        else:
            phone = PhoneLite.from_dict(_phone)




        main_assignment_code = d.pop("mainAssignmentCode", UNSET)

        status = cast(List[str], d.pop("status", UNSET))


        is_active_employee = d.pop("isActiveEmployee", UNSET)

        is_hosted = d.pop("isHosted", UNSET)

        _expiration = d.pop("expiration", UNSET)
        expiration: Union[Unset, datetime.datetime]
        if isinstance(_expiration,  Unset) or _expiration is None:
            expiration = UNSET
        else:
            expiration = isoparse(_expiration)




        _modified = d.pop("modified", UNSET)
        modified: Union[Unset, datetime.datetime]
        if isinstance(_modified,  Unset) or _modified is None:
            modified = UNSET
        else:
            modified = isoparse(_modified)




        employee_id = d.pop("employeeId", UNSET)

        lastnames = cast(List[str], d.pop("lastnames", UNSET))


        forenames = cast(List[str], d.pop("forenames", UNSET))


        assignments_codes = cast(List[str], d.pop("assignmentsCodes", UNSET))


        mobiles = []
        _mobiles = d.pop("mobiles", UNSET)
        for mobiles_item_data in (_mobiles or []):
            mobiles_item = PhoneLite.from_dict(mobiles_item_data)



            mobiles.append(mobiles_item)


        internal_lines = []
        _internal_lines = d.pop("internalLines", UNSET)
        for internal_lines_item_data in (_internal_lines or []):
            internal_lines_item = PhoneLite.from_dict(internal_lines_item_data)



            internal_lines.append(internal_lines_item)


        external_lines = []
        _external_lines = d.pop("externalLines", UNSET)
        for external_lines_item_data in (_external_lines or []):
            external_lines_item = PhoneLite.from_dict(external_lines_item_data)



            external_lines.append(external_lines_item)


        assignments = []
        _assignments = d.pop("assignments", UNSET)
        for assignments_item_data in (_assignments or []):
            assignments_item = Assignment.from_dict(assignments_item_data)



            assignments.append(assignments_item)


        infos = []
        _infos = d.pop("infos", UNSET)
        for infos_item_data in (_infos or []):
            infos_item = EmployeeInfos.from_dict(infos_item_data)



            infos.append(infos_item)


        roles = []
        _roles = d.pop("roles", UNSET)
        for roles_item_data in (_roles or []):
            roles_item = EmployeeRole.from_dict(roles_item_data)



            roles.append(roles_item)


        memberships = cast(List[str], d.pop("memberships", UNSET))


        cnu = cast(List[str], d.pop("cnu", UNSET))


        bap = cast(List[str], d.pop("bap", UNSET))


        contracts = cast(List[str], d.pop("contracts", UNSET))


        networks = cast(List[str], d.pop("networks", UNSET))


        employee_complete = cls(
            uid=uid,
            login=login,
            repository_id=repository_id,
            mail=mail,
            rot13mail=rot13mail,
            custom_rot_mail=custom_rot_mail,
            chosen_firstname=chosen_firstname,
            usualname=usualname,
            displayname=displayname,
            displayname_for_file=displayname_for_file,
            phone=phone,
            main_assignment_code=main_assignment_code,
            status=status,
            is_active_employee=is_active_employee,
            is_hosted=is_hosted,
            expiration=expiration,
            modified=modified,
            employee_id=employee_id,
            lastnames=lastnames,
            forenames=forenames,
            assignments_codes=assignments_codes,
            mobiles=mobiles,
            internal_lines=internal_lines,
            external_lines=external_lines,
            assignments=assignments,
            infos=infos,
            roles=roles,
            memberships=memberships,
            cnu=cnu,
            bap=bap,
            contracts=contracts,
            networks=networks,
        )

        employee_complete.additional_properties = d
        return employee_complete

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
