from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING

from typing import List


from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import Union
from ..types import UNSET, Unset






T = TypeVar("T", bound="Registering")


@_attrs_define
class Registering:
    """ Description d'une inscription pédagogique

        Attributes:
            establishment (Union[Unset, str]): Code établissement
            year (Union[Unset, int]): Année d'inscription
            scheme (Union[Unset, str]): Régime d'inscription
            section (Union[Unset, str]): Section disciplinaire
            level (Union[Unset, str]): Type de diplôme
            cursus (Union[Unset, str]): Cursus
            structure (Union[Unset, str]): Code de la structure d'accueil
            diploma (Union[Unset, str]): Code de diplôme
            code (Union[Unset, str]): Code étape (avec préfixe et version)
            iae (Union[Unset, str]): Code étape avec la version)
            iae_code (Union[Unset, str]): Code étape
            iae_version (Union[Unset, str]): Version du code étape
            label (Union[Unset, str]): Libellé de la formation
            is_main (Union[Unset, bool]): Témoin d'inscription principale
            reference (Union[Unset, str]): Référence de l'étudiant
            active (Union[Unset, bool]): Témoin d'activité de l'inscription
     """

    establishment: Union[Unset, str] = UNSET
    year: Union[Unset, int] = UNSET
    scheme: Union[Unset, str] = UNSET
    section: Union[Unset, str] = UNSET
    level: Union[Unset, str] = UNSET
    cursus: Union[Unset, str] = UNSET
    structure: Union[Unset, str] = UNSET
    diploma: Union[Unset, str] = UNSET
    code: Union[Unset, str] = UNSET
    iae: Union[Unset, str] = UNSET
    iae_code: Union[Unset, str] = UNSET
    iae_version: Union[Unset, str] = UNSET
    label: Union[Unset, str] = UNSET
    is_main: Union[Unset, bool] = UNSET
    reference: Union[Unset, str] = UNSET
    active: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        establishment = self.establishment

        year = self.year

        scheme = self.scheme

        section = self.section

        level = self.level

        cursus = self.cursus

        structure = self.structure

        diploma = self.diploma

        code = self.code

        iae = self.iae

        iae_code = self.iae_code

        iae_version = self.iae_version

        label = self.label

        is_main = self.is_main

        reference = self.reference

        active = self.active


        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if establishment is not UNSET:
            field_dict["establishment"] = establishment
        if year is not UNSET:
            field_dict["year"] = year
        if scheme is not UNSET:
            field_dict["scheme"] = scheme
        if section is not UNSET:
            field_dict["section"] = section
        if level is not UNSET:
            field_dict["level"] = level
        if cursus is not UNSET:
            field_dict["cursus"] = cursus
        if structure is not UNSET:
            field_dict["structure"] = structure
        if diploma is not UNSET:
            field_dict["diploma"] = diploma
        if code is not UNSET:
            field_dict["code"] = code
        if iae is not UNSET:
            field_dict["iae"] = iae
        if iae_code is not UNSET:
            field_dict["iaeCode"] = iae_code
        if iae_version is not UNSET:
            field_dict["iaeVersion"] = iae_version
        if label is not UNSET:
            field_dict["label"] = label
        if is_main is not UNSET:
            field_dict["isMain"] = is_main
        if reference is not UNSET:
            field_dict["reference"] = reference
        if active is not UNSET:
            field_dict["active"] = active

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        if not src_dict:
            return None
        d = src_dict.copy()
        establishment = d.pop("establishment", UNSET)

        year = d.pop("year", UNSET)

        scheme = d.pop("scheme", UNSET)

        section = d.pop("section", UNSET)

        level = d.pop("level", UNSET)

        cursus = d.pop("cursus", UNSET)

        structure = d.pop("structure", UNSET)

        diploma = d.pop("diploma", UNSET)

        code = d.pop("code", UNSET)

        iae = d.pop("iae", UNSET)

        iae_code = d.pop("iaeCode", UNSET)

        iae_version = d.pop("iaeVersion", UNSET)

        label = d.pop("label", UNSET)

        is_main = d.pop("isMain", UNSET)

        reference = d.pop("reference", UNSET)

        active = d.pop("active", UNSET)

        registering = cls(
            establishment=establishment,
            year=year,
            scheme=scheme,
            section=section,
            level=level,
            cursus=cursus,
            structure=structure,
            diploma=diploma,
            code=code,
            iae=iae,
            iae_code=iae_code,
            iae_version=iae_version,
            label=label,
            is_main=is_main,
            reference=reference,
            active=active,
        )

        registering.additional_properties = d
        return registering

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
